import java.awt.*;

public class Ball
{
	private R2Vector center;	// Position vector of center.
	private R2Vector velocity;	// Displacement per unit time.
	private double radius;
	private Color color;
	private static final double friction = .005; // Between 0 and 1.

	public Ball(R2Vector cent, double rad, R2Vector vel, Color c){
		center = cent.copy();
		radius = rad;
		color = c;
		velocity = vel.copy();
	}

	public Ball(double initX, double initY, double rad, 
				double velX, double velY, Color c)
		{ this(new R2Vector(initX, initY), rad, new R2Vector(velX, velY), c); }

	public R2Vector getCenter(){ return center; }

	public void setCenter(R2Vector newCenter){ center = newCenter.copy(); }

	public double getRadius(){ return radius; }

	public void setVelocity(R2Vector newVel){ velocity = newVel.copy(); }

	public R2Vector getVelocity(){ return velocity.copy(); }

	// Update position using velocity.
	public void move(){
		center.add(velocity);
		bounce();
		velocity.mult(1 - friction);
		if (velocity.length() < .05) velocity.mult(0);
	}

	// Adjusts velocity and position if the ball hits a wall.
	private void bounce(){
		if ((center.y > Animator.getSceneHeight() - radius) || (center.y < radius))
			{ velocity.y = -velocity.y;  center.y = center.y + velocity.y; }
		if ((center.x > Animator.getSceneWidth() - radius) || (center.x < radius))
			{ velocity.x = -velocity.x;  center.x = center.x + velocity.x; }
	}

	public void draw(Graphics g)
	{
		g.setColor(color);
		int diam = (int)(Math.round(2*radius));
		g.fillOval((int)(Math.round(center.x-radius)),(int)(Math.round(center.y-radius)),diam,diam);
//		g.drawOval((int)(Math.round(center.x-radius)),(int)(Math.round(center.y-radius)),diam,diam);
	}
}
